import { addSchema } from "@kubernetes-models/apimachinery/_schemas/IoK8sApimachineryPkgApisMetaV1ObjectMeta";
import { Model, setSchema, createTypeMetaGuard } from "@kubernetes-models/base";
import { register } from "@kubernetes-models/validate";
const schemaId = "pipelinesascode.tekton.dev.v1alpha1.Repository";
const schema = {
    "type": "object",
    "properties": {
        "apiVersion": {
            "type": "string",
            "enum": [
                "pipelinesascode.tekton.dev/v1alpha1"
            ]
        },
        "kind": {
            "type": "string",
            "enum": [
                "Repository"
            ]
        },
        "metadata": {
            "oneOf": [
                {
                    "$ref": "io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta#"
                },
                {
                    "type": "null"
                }
            ]
        },
        "spec": {
            "properties": {
                "settings": {
                    "type": "object",
                    "properties": {
                        "policy": {
                            "type": "object",
                            "properties": {
                                "ok_to_test": {
                                    "type": "array",
                                    "items": {
                                        "type": "string"
                                    },
                                    "nullable": true
                                },
                                "pull_request": {
                                    "type": "array",
                                    "items": {
                                        "type": "string"
                                    },
                                    "nullable": true
                                }
                            },
                            "nullable": true
                        },
                        "github_app_token_scope_repos": {
                            "type": "array",
                            "items": {
                                "type": "string"
                            },
                            "nullable": true
                        },
                        "pipelinerun_provenance": {
                            "type": "string",
                            "enum": [
                                "source",
                                "default_branch"
                            ],
                            "nullable": true
                        }
                    },
                    "nullable": true
                },
                "concurrency_limit": {
                    "type": "integer",
                    "nullable": true
                },
                "url": {
                    "type": "string",
                    "nullable": true
                },
                "type": {
                    "type": "string",
                    "enum": [
                        "github",
                        "gitea",
                        "bitbucket",
                        "gitlab",
                        "bitbucket-enteprise"
                    ],
                    "nullable": true
                },
                "params": {
                    "type": "array",
                    "items": {
                        "type": "object",
                        "required": [
                            "name"
                        ],
                        "properties": {
                            "name": {
                                "type": "string"
                            },
                            "value": {
                                "type": "string",
                                "nullable": true
                            },
                            "filter": {
                                "type": "string",
                                "nullable": true
                            },
                            "secret_ref": {
                                "type": "object",
                                "required": [
                                    "name",
                                    "key"
                                ],
                                "properties": {
                                    "key": {
                                        "type": "string",
                                        "default": "secret"
                                    },
                                    "name": {
                                        "type": "string"
                                    }
                                },
                                "nullable": true
                            }
                        }
                    },
                    "nullable": true
                },
                "incoming": {
                    "type": "array",
                    "items": {
                        "type": "object",
                        "properties": {
                            "type": {
                                "type": "string",
                                "enum": [
                                    "webhook-url"
                                ],
                                "nullable": true
                            },
                            "params": {
                                "type": "array",
                                "items": {
                                    "type": "string"
                                },
                                "nullable": true
                            },
                            "targets": {
                                "type": "array",
                                "items": {
                                    "type": "string"
                                },
                                "nullable": true
                            },
                            "secret": {
                                "type": "object",
                                "properties": {
                                    "key": {
                                        "type": "string",
                                        "default": "secret",
                                        "nullable": true
                                    },
                                    "name": {
                                        "type": "string",
                                        "nullable": true
                                    }
                                },
                                "nullable": true
                            }
                        }
                    },
                    "nullable": true
                },
                "git_provider": {
                    "type": "object",
                    "properties": {
                        "url": {
                            "type": "string",
                            "nullable": true
                        },
                        "user": {
                            "type": "string",
                            "nullable": true
                        },
                        "type": {
                            "type": "string",
                            "nullable": true
                        },
                        "secret": {
                            "type": "object",
                            "properties": {
                                "key": {
                                    "type": "string",
                                    "default": "provider.token",
                                    "nullable": true
                                },
                                "name": {
                                    "type": "string",
                                    "nullable": true
                                }
                            },
                            "nullable": true
                        },
                        "webhook_secret": {
                            "type": "object",
                            "properties": {
                                "key": {
                                    "type": "string",
                                    "default": "webhook.secret",
                                    "nullable": true
                                },
                                "name": {
                                    "type": "string",
                                    "nullable": true
                                }
                            },
                            "nullable": true
                        }
                    },
                    "nullable": true
                }
            },
            "type": "object",
            "nullable": true
        }
    },
    "required": [
        "apiVersion",
        "kind"
    ]
};
/**
 * Schema for the repository API
 */
export class Repository extends Model {
    constructor(data) {
        super({
            apiVersion: Repository.apiVersion,
            kind: Repository.kind,
            ...data
        });
    }
}
Repository.apiVersion = "pipelinesascode.tekton.dev/v1alpha1";
Repository.kind = "Repository";
Repository.is = createTypeMetaGuard(Repository);
setSchema(Repository, schemaId, () => {
    addSchema();
    register(schemaId, schema);
});
